@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package PDL::Graphics::Prima;
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 package Prima::Plot;
 use PDL::Lite;
@@ -795,16 +795,18 @@ sub on_mouseup {
 sub get_image {
 	my $self = shift;
 	
-	# Build a prima image canvas and draw to it:
-	my $image = Prima::Image->create(
-		height => $self->height,
-		width => $self->width,
-#		size => [$self->size],
-		backColor => $self->backColor,
-	) or die "Can't create an image!\n";
-	$self->on_paint($image);
-	return $image;
-#	return $::application->get_image($self->client_to_screen($self->origin), $self->size);
+# Not working:
+#	# Build a prima image canvas and draw to it:
+#	my $image = Prima::Image->create(
+#		height => $self->height,
+#		width => $self->width,
+##		size => [$self->size],
+#		backColor => $self->backColor,
+#	) or die "Can't create an image!\n";
+#	$self->on_paint($image);
+#	return $image;
+
+	return $::application->get_image($self->client_to_screen($self->origin), $self->size);
 }
 
 use Prima::PS::Drawable;
